@@ -468,6 +468,9 @@ class Column(gobject.GObject):
         else:
             raise ValueError("the type %s is not supported yet" % data_type)
 
+        renderer.connect('editing-started', self._on_renderer__editing_started,
+                         model, self.attribute)
+
         return renderer, prop
 
     # CellRenderers
@@ -572,6 +575,12 @@ class Column(gobject.GObject):
         renderer.set_data('kiwilist::radio-active', new)
         self._objectlist.emit('cell-edited', new, attr)
 
+    def _on_renderer__editing_started(self, renderer, editable, path,
+                                      model, attr):
+        obj = model[path][COL_MODEL]
+        self._objectlist.emit('cell-editing-started', obj, attr,
+                              renderer, editable)
+
     def _on_renderer_text__edited(self, renderer, path, text,
                                   model, attr, column, from_string):
         obj = model[path][COL_MODEL]
@@ -924,6 +933,8 @@ class ObjectList(gtk.HBox):
         - Emitted when a row is clicked with the right mouse button.
       - B{cell-edited} (list, object, attribute):
         - Emitted when a cell is edited.
+      - B{cell-editing-started} (list, object, attribute, renderer, editable):
+        - Emitted when the user starts to edit a cell
       - B{has-rows} (list, bool):
         - Emitted when the objectlist goes from an empty to a non-empty
           state or vice verse.
@@ -956,6 +967,9 @@ class ObjectList(gtk.HBox):
     # edited object, attribute name
     gsignal('cell-edited', object, str)
 
+    # object to edit, attribute name, renderer, renderers' editable
+    gsignal('cell-editing-started', object, str, object, object)
+
     # emitted when empty or non-empty status changes
     gsignal('has-rows', bool)
 
@@ -1626,6 +1640,11 @@ class ObjectList(gtk.HBox):
 
         return column.treeview_column
 
+    def set_instance_iter(self, item, treeiter):
+        """Sets the treeiter related an object in the list
+        """
+        self._iters[item] = treeiter
+
     def set_spinbutton_digits(self, column_name, digits):
         """Set the number of precision digits used by the spinbutton in
         a column.
