@@ -130,15 +130,3 @@ def gsignal(name, *args, **kwargs):
                 "gobject.SIGNAL_RUN_LAST")
 
         dict[name] = (flags, retval, args)
-
-
-def quote(msg):
-    """
-    Similar to urllib.quote but for glibs GMarkup
-    :param msg: string to quote
-    :returns: quoted string
-    """
-    msg = msg.replace('&', '&amp;')
-    msg = msg.replace('<', '&lt;')
-    msg = msg.replace('>', '&gt;')
-    return msg
