@@ -3,6 +3,7 @@ import unittest
 from gtk import gdk
 
 from kiwi import ValueUnset
+from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
 from kiwi.ui.proxy import Proxy
 from kiwi.ui.widgets.button import ProxyButton
@@ -96,10 +97,17 @@ class TestProxy(unittest.TestCase):
         self.view.entry.set_text('bar')
         self.assertEqual(self.model.entry, 'bar')
 
+        # If the widget is insensitive, it should not change the model
+        self.view.entry.set_sensitive(False)
+        self.view.entry.set_text('bin')
+        self.assertEqual(self.model.entry, 'bar')
+
     def testLabel(self):
         self.assertEqual(self.model.label, 'label')
         self.view.label.set_text('other label')
-        self.assertEqual(self.model.label, 'other label')
+        # When the proxy label is updated, the model should not change. Labels
+        # are non interactive widget, and the user cannot edit the value.
+        self.assertEqual(self.model.label, 'label')
 
     def testRadioButton(self):
         self.assertEqual(self.model.radiobutton, 'first')
@@ -123,6 +131,11 @@ class TestProxy(unittest.TestCase):
         self.view.spinbutton.set_text("200")
         self.assertEqual(self.model.spinbutton, 200)
 
+        # If the widget is insensitive, it should not change the model
+        self.view.spinbutton.set_sensitive(False)
+        self.view.spinbutton.set_text('400')
+        self.assertEqual(self.model.spinbutton, 200)
+
     def testTextView(self):
         self.assertEqual(self.model.textview, 'sliff')
         self.view.textview.get_buffer().set_text('sloff')
@@ -164,3 +177,22 @@ class TestProxy(unittest.TestCase):
         self.assertEqual(self.view.entry.get_text(), "")
         self.view.spinbutton.update(ValueUnset)
         self.assertEqual(self.view.spinbutton.get_text(), "")
+
+    def testValueChangeWhenWidgetInalid(self):
+        def validate_entry(entry, value):
+            if entry.make_invalid:
+                return ValidationError("")
+
+        self.view.entry.connect('validate', validate_entry)
+
+        self.view.entry.make_invalid = False
+        self.view.entry.update("Propagated immediatly")
+        self.assertEqual(self.model.entry, "Propagated immediatly")
+
+        self.view.entry.make_invalid = True
+        self.view.entry.update("Propagated later")
+        self.assertEqual(self.model.entry, "Propagated immediatly")
+
+        self.view.entry.make_invalid = False
+        self.view.entry.validate(force=True)
+        self.assertEqual(self.model.entry, "Propagated later")
